@@ -1,7 +1,7 @@
 """
 Publishes messages to a ROS topic
 
-COMPAS FAB v0.22.0
+COMPAS FAB v0.25.0
 """
 import time
 
@@ -9,7 +9,7 @@ from ghpythonlib.componentbase import executingcomponent as component
 from roslibpy import Topic
 from scriptcontext import sticky as st
 
-from compas_fab.backends.ros import ROSmsg
+from compas_fab.backends.ros.messages import ROSmsg
 from compas_fab.ghpython.components import create_id
 
 
